/*
 * This software is licensed under the terms of the MIT License.
 * See COPYING for further information.
 * ---
 * Copyright (c) 2011-2024, Lukas Weber <laochailan@web.de>.
 * Copyright (c) 2012-2024, Andrei Alexeyev <akari@taisei-project.org>.
 */

#include "gamemode.h"
#include "log.h"

void gamemode_init(void) {
	log_info("Compiled without GameMode integration");
}

void gamemode_shutdown(void) {

}
